/* -*- buffer-read-only: t -*-
 * !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
 * This file is built by regen/mk_invlists.pl from Unicode::UCD.
 * Any changes made here will be lost!
 */

/* See the generating file for comments */


#ifndef PERL_IN_XSUB_RE

static UV Latin1_invlist[] = {
	2,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	0,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	256,
	0
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV AboveLatin1_invlist[] = {
	1,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	256
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV ASCII_invlist[] = {
	2,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	0,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	128,
	0
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV L1Cased_invlist[] = {
	16,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	65,
	91,
	97,
	123,
	170,
	171,
	181,
	182,
	186,
	187,
	192,
	215,
	216,
	247,
	248,
	443
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV VertSpace_invlist[] = {
	6,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	10,
	14,
	133,
	134,
	8232,
	8234
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV PerlSpace_invlist[] = {
	4,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	9,
	14,
	32,
	33
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV XPerlSpace_invlist[] = {
	22,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	9,
	14,
	32,
	33,
	133,
	134,
	160,
	161,
	5760,
	5761,
	6158,
	6159,
	8192,
	8203,
	8232,
	8234,
	8239,
	8240,
	8287,
	8288,
	12288,
	12289
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV PosixAlnum_invlist[] = {
	6,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	48,
	58,
	65,
	91,
	97,
	123
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV L1PosixAlnum_invlist[] = {
	18,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	48,
	58,
	65,
	91,
	97,
	123,
	170,
	171,
	181,
	182,
	186,
	187,
	192,
	215,
	216,
	247,
	248,
	706
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV PosixAlpha_invlist[] = {
	4,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	65,
	91,
	97,
	123
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV L1PosixAlpha_invlist[] = {
	16,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	65,
	91,
	97,
	123,
	170,
	171,
	181,
	182,
	186,
	187,
	192,
	215,
	216,
	247,
	248,
	706
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV PosixBlank_invlist[] = {
	4,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	9,
	10,
	32,
	33
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV XPosixBlank_invlist[] = {
	18,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	9,
	10,
	32,
	33,
	160,
	161,
	5760,
	5761,
	6158,
	6159,
	8192,
	8203,
	8239,
	8240,
	8287,
	8288,
	12288,
	12289
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV PosixCntrl_invlist[] = {
	4,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	0,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	32,
	127,
	128,
	0
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV XPosixCntrl_invlist[] = {
	4,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	0,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	32,
	127,
	160,
	0
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV PosixDigit_invlist[] = {
	2,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	48,
	58
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV PosixGraph_invlist[] = {
	2,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	33,
	127
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV L1PosixGraph_invlist[] = {
	4,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	33,
	127,
	161,
	888
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV PosixLower_invlist[] = {
	2,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	97,
	123
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV L1PosixLower_invlist[] = {
	12,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	97,
	123,
	170,
	171,
	181,
	182,
	186,
	187,
	223,
	247,
	248,
	256
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV PosixPrint_invlist[] = {
	2,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	32,
	127
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV L1PosixPrint_invlist[] = {
	4,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	32,
	127,
	160,
	888
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV PosixPunct_invlist[] = {
	8,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	33,
	48,
	58,
	65,
	91,
	97,
	123,
	127
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV L1PosixPunct_invlist[] = {
	20,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	33,
	48,
	58,
	65,
	91,
	97,
	123,
	127,
	161,
	162,
	167,
	168,
	171,
	172,
	182,
	184,
	187,
	188,
	191,
	192
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV PosixSpace_invlist[] = {
	4,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	9,
	14,
	32,
	33
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV XPosixSpace_invlist[] = {
	22,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	9,
	14,
	32,
	33,
	133,
	134,
	160,
	161,
	5760,
	5761,
	6158,
	6159,
	8192,
	8203,
	8232,
	8234,
	8239,
	8240,
	8287,
	8288,
	12288,
	12289
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV PosixUpper_invlist[] = {
	2,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	65,
	91
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV L1PosixUpper_invlist[] = {
	6,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	65,
	91,
	192,
	215,
	216,
	223
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV PosixWord_invlist[] = {
	8,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	48,
	58,
	65,
	91,
	95,
	96,
	97,
	123
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV L1PosixWord_invlist[] = {
	20,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	48,
	58,
	65,
	91,
	95,
	96,
	97,
	123,
	170,
	171,
	181,
	182,
	186,
	187,
	192,
	215,
	216,
	247,
	248,
	706
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV PosixXDigit_invlist[] = {
	6,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	48,
	58,
	65,
	71,
	97,
	103
};

#endif

#ifndef PERL_IN_XSUB_RE

static UV XPosixXDigit_invlist[] = {
	12,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	48,
	58,
	65,
	71,
	97,
	103,
	65296,
	65306,
	65313,
	65319,
	65345,
	65351
};

#endif

static UV NonL1_Perl_Non_Final_Folds_invlist[] = {
	44,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	700,
	701,
	776,
	777,
	787,
	788,
	834,
	835,
	940,
	941,
	942,
	943,
	945,
	946,
	951,
	952,
	953,
	954,
	961,
	962,
	965,
	966,
	969,
	970,
	974,
	975,
	1381,
	1382,
	1396,
	1397,
	1406,
	1407,
	7936,
	7944,
	7968,
	7976,
	8032,
	8040,
	8048,
	8049,
	8052,
	8053,
	8060,
	8061
};

#ifndef PERL_IN_XSUB_RE

static UV _Perl_Multi_Char_Folds_invlist[] = {
	58,	/* Number of elements */
	0,	/* Current iteration position */
	0,	/* Cache of previous search index result */
	290655244, /* Version and data structure type */
	1,	/* 0 if this is the first element of the list proper;
		   1 if the next element is the first */
	223,
	224,
	304,
	305,
	329,
	330,
	496,
	497,
	912,
	913,
	944,
	945,
	1415,
	1416,
	7830,
	7835,
	7838,
	7839,
	8016,
	8017,
	8018,
	8019,
	8020,
	8021,
	8022,
	8023,
	8064,
	8112,
	8114,
	8117,
	8118,
	8120,
	8124,
	8125,
	8130,
	8133,
	8134,
	8136,
	8140,
	8141,
	8146,
	8148,
	8150,
	8152,
	8162,
	8165,
	8166,
	8168,
	8178,
	8181,
	8182,
	8184,
	8188,
	8189,
	64256,
	64263,
	64275,
	64280
};

#endif

/* ex: set ro: */
